@@ -53,18 +53,18 @@ from .literals import (
 )
 from .type_defs import (
     BuildBatchFilterTypeDef,
-    DescribeCodeCoveragesOutputTypeDef,
-    DescribeTestCasesOutputTypeDef,
-    ListBuildBatchesForProjectOutputTypeDef,
-    ListBuildBatchesOutputTypeDef,
-    ListBuildsForProjectOutputTypeDef,
-    ListBuildsOutputTypeDef,
-    ListProjectsOutputTypeDef,
-    ListReportGroupsOutputTypeDef,
-    ListReportsForReportGroupOutputTypeDef,
-    ListReportsOutputTypeDef,
-    ListSharedProjectsOutputTypeDef,
-    ListSharedReportGroupsOutputTypeDef,
+    DescribeCodeCoveragesOutputResponseTypeDef,
+    DescribeTestCasesOutputResponseTypeDef,
+    ListBuildBatchesForProjectOutputResponseTypeDef,
+    ListBuildBatchesOutputResponseTypeDef,
+    ListBuildsForProjectOutputResponseTypeDef,
+    ListBuildsOutputResponseTypeDef,
+    ListProjectsOutputResponseTypeDef,
+    ListReportGroupsOutputResponseTypeDef,
+    ListReportsForReportGroupOutputResponseTypeDef,
+    ListReportsOutputResponseTypeDef,
+    ListSharedProjectsOutputResponseTypeDef,
+    ListSharedReportGroupsOutputResponseTypeDef,
     PaginatorConfigTypeDef,
     ReportFilterTypeDef,
     TestCaseFilterTypeDef,
@@ -88,7 +88,8 @@ __all__ = (
 
 class DescribeCodeCoveragesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#describecodecoveragespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#describecodecoveragespaginator)
     """
 
     def paginate(
@@ -100,71 +101,75 @@ class DescribeCodeCoveragesPaginator(Boto3Paginator):
         minLineCoveragePercentage: float = None,
         maxLineCoveragePercentage: float = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeCodeCoveragesOutputTypeDef]:
+    ) -> Iterator[DescribeCodeCoveragesOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#describecodecoveragespaginator)
         """
 
 
 class DescribeTestCasesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#describetestcasespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#describetestcasespaginator)
     """
 
     def paginate(
         self,
         *,
         reportArn: str,
-        filter: TestCaseFilterTypeDef = None,
+        filter: "TestCaseFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeTestCasesOutputTypeDef]:
+    ) -> Iterator[DescribeTestCasesOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#describetestcasespaginator)
         """
 
 
 class ListBuildBatchesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildbatchespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildbatchespaginator)
     """
 
     def paginate(
         self,
         *,
-        filter: BuildBatchFilterTypeDef = None,
+        filter: "BuildBatchFilterTypeDef" = None,
         sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListBuildBatchesOutputTypeDef]:
+    ) -> Iterator[ListBuildBatchesOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildbatchespaginator)
         """
 
 
 class ListBuildBatchesForProjectPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildbatchesforprojectpaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildbatchesforprojectpaginator)
     """
 
     def paginate(
         self,
         *,
         projectName: str = None,
-        filter: BuildBatchFilterTypeDef = None,
+        filter: "BuildBatchFilterTypeDef" = None,
         sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListBuildBatchesForProjectOutputTypeDef]:
+    ) -> Iterator[ListBuildBatchesForProjectOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildbatchesforprojectpaginator)
         """
 
 
 class ListBuildsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildspaginator)
     """
 
     def paginate(
@@ -172,16 +177,17 @@ class ListBuildsPaginator(Boto3Paginator):
         *,
         sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListBuildsOutputTypeDef]:
+    ) -> Iterator[ListBuildsOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildspaginator)
         """
 
 
 class ListBuildsForProjectPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildsforprojectpaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildsforprojectpaginator)
     """
 
     def paginate(
@@ -190,16 +196,17 @@ class ListBuildsForProjectPaginator(Boto3Paginator):
         projectName: str,
         sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListBuildsForProjectOutputTypeDef]:
+    ) -> Iterator[ListBuildsForProjectOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildsforprojectpaginator)
         """
 
 
 class ListProjectsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listprojectspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listprojectspaginator)
     """
 
     def paginate(
@@ -208,16 +215,17 @@ class ListProjectsPaginator(Boto3Paginator):
         sortBy: ProjectSortByTypeType = None,
         sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListProjectsOutputTypeDef]:
+    ) -> Iterator[ListProjectsOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listprojectspaginator)
         """
 
 
 class ListReportGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportgroupspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportgroupspaginator)
     """
 
     def paginate(
@@ -226,34 +234,36 @@ class ListReportGroupsPaginator(Boto3Paginator):
         sortOrder: SortOrderTypeType = None,
         sortBy: ReportGroupSortByTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListReportGroupsOutputTypeDef]:
+    ) -> Iterator[ListReportGroupsOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportgroupspaginator)
         """
 
 
 class ListReportsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportspaginator)
     """
 
     def paginate(
         self,
         *,
         sortOrder: SortOrderTypeType = None,
-        filter: ReportFilterTypeDef = None,
+        filter: "ReportFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListReportsOutputTypeDef]:
+    ) -> Iterator[ListReportsOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListReports.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListReports.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportspaginator)
         """
 
 
 class ListReportsForReportGroupPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportsforreportgrouppaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportsforreportgrouppaginator)
     """
 
     def paginate(
@@ -261,18 +271,19 @@ class ListReportsForReportGroupPaginator(Boto3Paginator):
         *,
         reportGroupArn: str,
         sortOrder: SortOrderTypeType = None,
-        filter: ReportFilterTypeDef = None,
+        filter: "ReportFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListReportsForReportGroupOutputTypeDef]:
+    ) -> Iterator[ListReportsForReportGroupOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportsforreportgrouppaginator)
         """
 
 
 class ListSharedProjectsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listsharedprojectspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listsharedprojectspaginator)
     """
 
     def paginate(
@@ -281,16 +292,17 @@ class ListSharedProjectsPaginator(Boto3Paginator):
         sortBy: SharedResourceSortByTypeType = None,
         sortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListSharedProjectsOutputTypeDef]:
+    ) -> Iterator[ListSharedProjectsOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listsharedprojectspaginator)
         """
 
 
 class ListSharedReportGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listsharedreportgroupspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listsharedreportgroupspaginator)
     """
 
     def paginate(
@@ -299,8 +311,8 @@ class ListSharedReportGroupsPaginator(Boto3Paginator):
         sortOrder: SortOrderTypeType = None,
         sortBy: SharedResourceSortByTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListSharedReportGroupsOutputTypeDef]:
+    ) -> Iterator[ListSharedReportGroupsOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listsharedreportgroupspaginator)
         """
