@@ -20,7 +20,6 @@ from .literals import (
     ArtifactPackagingType,
     ArtifactsTypeType,
     AuthTypeType,
-    BucketOwnerAccessType,
     BuildBatchPhaseTypeType,
     BuildPhaseTypeType,
     CacheModeType,
@@ -222,7 +221,6 @@ BuildArtifactsTypeDef = TypedDict(
         "overrideArtifactName": bool,
         "encryptionDisabled": bool,
         "artifactIdentifier": str,
-        "bucketOwnerAccess": BucketOwnerAccessType,
     },
     total=False,
 )
@@ -766,7 +764,6 @@ _OptionalProjectArtifactsTypeDef = TypedDict(
         "overrideArtifactName": bool,
         "encryptionDisabled": bool,
         "artifactIdentifier": str,
-        "bucketOwnerAccess": BucketOwnerAccessType,
     },
     total=False,
 )
@@ -1056,7 +1053,6 @@ _OptionalS3LogsConfigTypeDef = TypedDict(
     {
         "location": str,
         "encryptionDisabled": bool,
-        "bucketOwnerAccess": BucketOwnerAccessType,
     },
     total=False,
 )
